% This script is to be used to run the molecular dynamics simulation,
% gather the output, perform the wavelet transform at each time step and
% then reduce it using SVD

clear
clc
close all

% Number of particles
N = 20;

% Time info
T = 4;
dt = 0.01;

% Run the MD simulation
[X,V] = Verlet(N,T,dt);

% Get the dimensions of the position info
[~,~,nt] = size(X);

% Number of frequencies to test
w = logspace(-2,1);


% For t=1,2,3,4
for i=1:4
    
    % Perform the wavelet transform on the x particle data
    [C] = cwt(X(:,:,(i*100)+1),w,'morl');
    
    C = C';
    
    % Then the singular value decomposition
    [U,S,V] = svd(C);
    
    close all
    
    % Plot before the svd
    hold on
    plot(C(:,1),'LineWidth',1.5);
    plot(C(:,25),'r','LineWidth',1.5);
    plot(C(:,50),'g','LineWidth',1.5);
    xlabel('Particle','FontSize',16);
    ylabel('Wavelet Coefficient','FontSize',16);
    title(strcat('Wavelet coefficient at t = ',num2str(i)),'FontSize',16);
    H=legend('w=0.01','w = 0.2947','w = 10');
    set(gca,'FontSize',16);
    hold off
    saveas(H,strcat('C_',num2str(i),'.png'))
    
    close all
    
    % Plot the u and v and singular values 
    semilogy(spdiags(S),'LineWidth',1.5);
    xlabel('Singular Values','FontSize',16);
    ylabel('Magnitude','FontSize',16);
    H=title(strcat('Singular Values for t = ',num2str(i)),'FontSize',16);
    set(gca,'FontSize',16);
    saveas(H,strcat('singular_values',num2str(i),'.png'))
    
    close all
    
    plot(U(:,1:4),'LineWidth',1.5);
    xlabel('Particle','FontSize',16);
    ylabel('Reduced Wavelet Coefficient','FontSize',16);
    title(strcat('Reduced Wavelet coefficient at t = ',num2str(i)),'FontSize',16);
    H=legend('First basis','Second basis','Third basis','Fourth basis');
    set(gca,'FontSize',16);
    saveas(H,strcat('U_',num2str(i),'.png'))
    
    close all
    
    semilogx(logspace(-2,1),V(:,1:4),'LineWidth',1.5);
    xlabel('Frequency','FontSize',16);
    ylabel('Reduced Wavelet Coefficient','FontSize',16);
    title(strcat('Reduced Wavelet coefficient at t = ',num2str(i)),'FontSize',16);
    H=legend('First basis','Second basis','Third basis','Fourth basis');
    set(gca,'FontSize',16);
    saveas(H,strcat('V_',num2str(i),'.png'))
    close all
    
    
end
    
    
    